@@ -383,13 +383,10 @@ EXP_OPTION int verifyCertificateByOCSPWithIp(X509* pCert, const X509** caCerts,
 {
   OCSP_REQUEST *req = 0;
   OCSP_RESPONSE *resp = 0;
-  int err = ERR_OK, l1, i, j, nType, nCAs1, err2;
+  int err = ERR_OK, l1, i;
   byte nonce1[DIGEST_LEN+2];
   time_t tNow;
   X509* pCA = NULL;
-  X509* caCerts1[10];
-  X509* pNotCert1;
-  char szCN[200], szCA[30];
   
   RETURN_IF_NULL(pCert);
   //RETURN_IF_NULL(notaryCert);
@@ -831,7 +828,7 @@ EXP_OPTION int isCertSignedByCERT(const X509* cert, const X509* caCert)
 //--------------------------------------------------------
 int ddocCertCopySubstring(const char* szSrc, const char* szLabel, const char* szTerminator, char** szDest)
 {
-	int l;
+	ptrdiff_t l;
 	char *p1, *p2;
 
 	RETURN_IF_NULL_PARAM(szSrc);
@@ -846,11 +843,11 @@ int ddocCertCopySubstring(const char* szSrc, const char* szLabel, const char* sz
 		if(!p2)
 			p2 = strchr(p1, 0);
 		if(p2 && p2 > p1) {
-			l = (int)p2 - (int)p1 + 1;
+			l = p2 - p1 + 1;
 			*szDest = (char*)malloc(l);
 			if(*szDest) {
 				memset(*szDest, 0, l);
-				strncpy(*szDest, p1, (int)p2 - (int)p1);
+				strncpy(*szDest, p1, p2 - p1);
 			}
 		}
 	}
