@@ -588,7 +588,7 @@ EXP_OPTION const char* getSimpleFileName(const char* szFileName)
 //============================================================
 // Get the absolute filename with path
 //============================================================
-EXP_OPTION int getFullFileName(const char* szFileName, char* szDest, int len)
+EXP_OPTION int getFullFileName(const char* szFileName, char* szDest, size_t len)
 {
   int err = ERR_OK;
   memset(szDest, 0, len);
@@ -614,7 +614,7 @@ EXP_OPTION int getFullFileName(const char* szFileName, char* szDest, int len)
 //============================================================
 // Get the path part of full file name
 //============================================================
-EXP_OPTION int getFileNamePath(const char* szFileName, char* szPath, int len)
+EXP_OPTION int getFileNamePath(const char* szFileName, char* szPath, size_t len)
 {
   int nFound = 0, i, err = ERR_OK;
 
@@ -638,12 +638,13 @@ EXP_OPTION int getFileNamePath(const char* szFileName, char* szPath, int len)
 // Gets a new temporary filename
 // buf - filename buffer
 //============================================================
-EXP_OPTION int getTempFileName(char* szFileName, int len)
+EXP_OPTION int getTempFileName(char* szFileName, size_t len)
 {
 	char tbuf[200];
-        int f = 0;
 #ifdef WIN32
 	char* pFileName = 0;
+#else
+        int f = 0;
 #endif
 	RETURN_IF_NULL_PARAM(szFileName);
 	memset(szFileName, 0, len);
@@ -908,7 +909,8 @@ EXP_OPTION int ddocPrepareSignature(SignedDoc* pSigDoc, SignatureInfo** ppSigInf
 EXP_OPTION  int ddocGetSignedHash(SignatureInfo* pSigInfo, 
 		   char* pBuf, int* pBufLen, int enc, int bWithAsn1Prefix)
 {
-  int err = ERR_OK, l1 = 0;
+  int err = ERR_OK;
+  size_t l1 = 0;
   char buf1[50];
   DigiDocMemBuf *pMBuf;
 
